import os
import socket
import logging

from ..connector import Connector

class Server(Connector):
    """UNIX-socket server used to communicate with clients."""
    def __init__(self):
        Connector.__init__(self, 'unix')

    def delete_existing_socket(self):
        """Deletes the existing UNIX-socket if it exists."""
        if os.path.exists(self.host):
            os.remove(self.host)

    def start(self):
        """
        Binds the socket to file.

        :return: if the socket could be bound to the file
        :rType: bool
        """
        self.delete_existing_socket()
        try:
            self.socket.bind(self.host)
            logging.debug('Successfully bound socket to: %s' % self.host)
            return True
        except OSError as e:
            logging.error('Failed to create UNIX socket: %s' % e.strerror)
        
        return False

    def close(self):
        """Unbinds the socket and deletes the file."""
        self.socket.close()
        os.remove(self.host)




import os
import socket
import logging

from ..connector import Connector

class Server(Connector):
    """UDP-socket server used to communicate with clients."""
    def __init__(self):
        Connector.__init__(self, 'win32')

    def start(self):
        """
        Binds the socket to localhost.

        :return: if the socket could be bound to the host
        :rType: bool
        """
        try:
            self.socket.bind(self.host)
            logging.debug('Successfully bound socket to: %s:%s' % (self.host[0], self.host[1]))
            return True
        except OSError as e:
            logging.error('Failed to setup UDP socket server: %s' % e.strerror)
        
        return False




import os

DAEMON_VERSION='2.3'

UNIX_SOCKET_PATH='/tmp/pywalfox_socket'
WIN_SOCKET_HOST = ('127.0.0.1', 56744)

SUPPORTED_BROWSERS=['firefox']

HOME_PATH=os.path.expanduser('~')
XDG_CACHE_DIR = os.getenv('XDG_CACHE_HOME', os.path.join(HOME_PATH, '.cache'))
PYWAL_COLORS_PATH=os.path.join(XDG_CACHE_DIR, 'wal/colors')

APP_PATH=os.path.dirname(os.path.abspath(__file__))
BIN_PATH_UNIX=os.path.join(APP_PATH, 'bin/main.sh')
BIN_PATH_WIN=os.path.join(APP_PATH, 'bin/win.bat')
CSS_PATH=os.path.join(APP_PATH, 'assets/css')

FIREFOX_PATH_LINUX=os.path.join(HOME_PATH, '.mozilla/firefox/*.default-release')
FIREFOX_PATH_DARWIN=os.path.join(HOME_PATH, 'Library/Application\ Support/Firefox/Profiles/*.default-release*')
FIREFOX_PATH_WIN=os.path.join(HOME_PATH, 'AppData/Roaming/Mozilla/Firefox/Profiles/*.default-*')

LOG_FILE_PATH=os.path.join(APP_PATH, 'daemon.log')
LOG_FILE_COUNT=1
LOG_FILE_MAX_SIZE=1000*200 # 0.2 mb
LOG_FILE_FORMAT='[%(asctime)s] %(levelname)s:%(message)s'
LOG_FILE_DATE_FORMAT='%m-%d-%Y %I:%M:%S'

ACTIONS={
    'VERSION': 'debug:version',
    'OUTPUT': 'debug:output',
    'COLORS': 'action:colors',
    'INVALID_ACTION': 'action:invalid',
    'CSS_ENABLE': 'css:enable',
    'CSS_DISABLE': 'css:disable',
    'CSS_FONT_SIZE': 'css:font:size',
}




import os
import socket
import logging

from ..connector import Connector

class Client(Connector):
    """UDP-socket client used to communicate with the daemon."""
    def __init__(self):
        Connector.__init__(self, 'win32')

    def start(self):
        """
        Connects to the UDP socket.

        :return: if the connection to the socket was successfull
        :rType: bool
        """
        try:
            self.socket.connect(self.host)
            logging.debug('Successfully connected to UDP socket at: %s:%s' % (self.host[0], self.host[1]))
            return True
        except Exception as e:
            logging.error('Failed to connect to socket: %s' % str(e))

        return False
